@@ -42,7 +42,6 @@ from localstack.services.awslambda.lambda_utils import (
 )
 from localstack.services.generic_proxy import RegionBackend
 from localstack.services.install import INSTALL_DIR_STEPFUNCTIONS, install_go_lambda_runtime
-from localstack.utils import bootstrap
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_models import CodeSigningConfig, LambdaFunction
@@ -72,6 +71,7 @@ from localstack.utils.common import (
     to_str,
     unzip,
 )
+from localstack.utils.container_networking import get_main_container_name
 from localstack.utils.docker_utils import DOCKER_CLIENT
 from localstack.utils.functions import run_safe
 from localstack.utils.http import canonicalize_headers, parse_chunked_data
@@ -349,8 +349,6 @@ def process_apigateway_invocation(
 ):
     if path_params is None:
         path_params = {}
-    if stage_variables is None:
-        stage_variables = {}
     if request_context is None:
         request_context = {}
     try:
@@ -363,8 +361,7 @@ def process_apigateway_invocation(
         event["pathParameters"] = path_params
         event["resource"] = resource_path
         event["requestContext"] = request_context
-        if stage_variables:
-            event["stageVariables"] = stage_variables
+        event["stageVariables"] = stage_variables
         LOG.debug(
             "Running Lambda function %s from API Gateway invocation: %s %s",
             func_arn,
@@ -2138,13 +2135,13 @@ def validate_lambda_config():
         config.LAMBDA_DOCKER_NETWORK
         and config.is_in_docker
         and config.LAMBDA_DOCKER_NETWORK
-        not in DOCKER_CLIENT.get_networks(bootstrap.get_main_container_name())
+        not in DOCKER_CLIENT.get_networks(get_main_container_name())
     ):
         LOG.warning(
             "Your specified LAMBDA_DOCKER_NETWORK '%s' is not connected to the main LocalStack container '%s'. "
             "Lambda functionality might be severely limited.",
             config.LAMBDA_DOCKER_NETWORK,
-            bootstrap.get_main_container_name(),
+            get_main_container_name(),
         )
 
 
