@@ -22,9 +22,9 @@ from localstack.constants import (
     TEST_AWS_ACCOUNT_ID,
 )
 from localstack.utils.aws import aws_stack
-from localstack.utils.common import (
-    json_safe,
-    replace_response_content,
+from localstack.utils.http import replace_response_content
+from localstack.utils.json import json_safe
+from localstack.utils.strings import (
     short_uid,
     str_startswith_ignore_case,
     to_bytes,
@@ -34,8 +34,6 @@ from localstack.utils.common import (
 
 REGEX_FLAGS = re.MULTILINE | re.DOTALL
 
-AWS_BINARY_DATA_TYPE_STRING = 7
-
 
 class ErrorResponse(Exception):
     def __init__(self, response):
@@ -362,7 +360,9 @@ def extract_url_encoded_param_list(req_data, pattern):
     return result
 
 
-def parse_urlencoded_data(qs_data: Union[Dict, str, bytes], top_level_attribute: str):
+def parse_urlencoded_data(
+    qs_data: Union[Dict, str, bytes], top_level_attribute: str, second_level_attribute: str = ""
+):
     # TODO: potentially find a better way than calling moto here...
     from moto.core.responses import BaseResponse
 
@@ -374,6 +374,16 @@ def parse_urlencoded_data(qs_data: Union[Dict, str, bytes], top_level_attribute:
     response = BaseResponse()
     response.querystring = qs_data
     result = response._get_multi_param(top_level_attribute, skip_result_conversion=True)
+    if second_level_attribute:
+        for r in range(len(result)):
+            second_level_result = response._get_multi_param(
+                f"{top_level_attribute}.{r+1}.{second_level_attribute}", skip_result_conversion=True
+            )
+            inner_key = second_level_attribute.split(".")[
+                0
+            ]  # "MessageAttributes.entry".split('.')[0]
+            if second_level_result:
+                result[r][inner_key] = second_level_result
     return result
 
 
@@ -392,7 +402,13 @@ def calculate_crc32(content):
     return crc32(to_bytes(content)) & 0xFFFFFFFF
 
 
+# TODO Remove this constant with the function below
+AWS_BINARY_DATA_TYPE_STRING = 7
+
+
 def convert_to_binary_event_payload(result, event_type=None, message_type=None):
+    # TODO This encoding has been migrated to the ASF Serializer.
+    #  Remove this function after S3 and Kinesis have been migrated to ASF.
     # e.g.: https://docs.aws.amazon.com/AmazonS3/latest/API/RESTSelectObjectAppendix.html
     # e.g.: https://docs.aws.amazon.com/transcribe/latest/dg/event-stream.html
 
@@ -413,7 +429,10 @@ def convert_to_binary_event_payload(result, event_type=None, message_type=None):
         headers += header_value
 
     # construct body
-    body = bytes(result, DEFAULT_ENCODING)
+    if isinstance(result, str):
+        body = bytes(result, DEFAULT_ENCODING)
+    else:
+        body = result
 
     # calculate lengths
     headers_length = len(headers)
@@ -432,7 +451,7 @@ def convert_to_binary_event_payload(result, event_type=None, message_type=None):
     return result
 
 
-class LambdaResponse(object):
+class LambdaResponse:
     """Helper class to support multi_value_headers in Lambda responses"""
 
     def __init__(self):
@@ -446,7 +465,7 @@ class LambdaResponse(object):
         return self._content
 
 
-class MessageConversion(object):
+class MessageConversion:
     @staticmethod
     def fix_date_format(response):
         """Normalize date to format '2019-06-13T18:10:09.1234Z'"""
