@@ -309,6 +309,7 @@ def connect_api_gateway_to_http_with_lambda_proxy(
     auth_type=None,
     auth_creator_func=None,
     http_method=None,
+    client=None,
 ):
     if methods is None:
         methods = []
@@ -336,6 +337,7 @@ def connect_api_gateway_to_http_with_lambda_proxy(
         resources=resources,
         stage_name=stage_name,
         auth_creator_func=auth_creator_func,
+        client=client,
     )
 
 
@@ -665,7 +667,7 @@ def http_server(handler, host="127.0.0.1", port=None) -> str:
 
     host = host
     port = port or get_free_tcp_port()
-    thread = run_server(port, host, handler=handler, asynchronous=True)
+    thread = run_server(port, [host], handler=handler, asynchronous=True)
     url = f"http://{host}:{port}"
     assert poll_condition(
         lambda: is_port_open(port), timeout=5
